@@ -36,7 +36,11 @@ class TrainLog:
             
             for r in rs:
                 r = r[:-1]
-                rtn.append(r.split(','))
+                cs = r.split(',')
+                for c in cs:
+                    if len(rtn) == cs.index(c):
+                        rtn.append([])
+                    rtn[cs.index(c)].append(c)
             
             fs.close()
         except Exception as err:
